@@ -1383,7 +1383,7 @@ main (gint argc, gchar **argv)
     xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
     /* initialize Gtk+ */
-    if (!gtk_init_with_args (&argc, &argv, "", entries, PACKAGE, &error)) {
+    if (!gtk_init_with_args (&argc, &argv, NULL, entries, PACKAGE, &error)) {
         if (G_LIKELY (error)) {
             /* print error */
             g_print ("%s: %s.\n", G_LOG_DOMAIN, error->message);
