@@ -113,9 +113,6 @@ static void     xfce_settings_manager_dialog_style_updated   (GtkWidget
 static void     xfce_settings_manager_dialog_set_hover_style (XfceSettingsManagerDialog *dialog);
 static void     xfce_settings_manager_dialog_response        (GtkDialog                 *widget,
                                                               gint                       response_id);
-static void     xfce_settings_manager_dialog_header_style    (GtkWidget                 *header,
-                                                              GtkStyle                  *old_style,
-                                                              GtkWidget                 *ebox);
 static void     xfce_settings_manager_dialog_set_title       (XfceSettingsManagerDialog *dialog,
                                                               const gchar               *title,
                                                               const gchar               *icon_name,
@@ -219,10 +216,7 @@ static void
 xfce_settings_manager_dialog_init (XfceSettingsManagerDialog *dialog)
 {
     GtkWidget *dialog_vbox;
-    GtkWidget *ebox;
     GtkWidget *entry;
-    GtkWidget *hbox;
-    GtkWidget *header;
     GtkWidget *scroll;
     GtkWidget *viewport;
     GtkWidget *image;
@@ -249,49 +243,27 @@ xfce_settings_manager_dialog_init (XfceSettingsManagerDialog *dialog)
       xfconf_channel_get_int (dialog->channel, "/last/window-height", 500));
     xfce_settings_manager_dialog_set_title (dialog, NULL, NULL, NULL);
 
-    dialog->button_back = gtk_dialog_add_button (GTK_DIALOG (dialog), _("All _Settings"), GTK_RESPONSE_NONE);
-    image = gtk_image_new_from_icon_name ("go-previous", GTK_ICON_SIZE_BUTTON);
+    /* Add a buttonbox (Help, All Settings, Close) at bottom of the main box */
+    xfce_titled_dialog_create_action_area (XFCE_TITLED_DIALOG (dialog));
+
+    dialog->button_help = xfce_titled_dialog_add_button (XFCE_TITLED_DIALOG (dialog), _("_Help"), GTK_RESPONSE_HELP);
+    image = gtk_image_new_from_icon_name ("help-browser", GTK_ICON_SIZE_BUTTON);
+    gtk_button_set_image (GTK_BUTTON (dialog->button_help), image);
+
+    dialog->button_back = xfce_titled_dialog_add_button (XFCE_TITLED_DIALOG (dialog), _("All _Settings"), GTK_RESPONSE_NONE);
+    image = gtk_image_new_from_icon_name ("go-previous-symbolic", GTK_ICON_SIZE_BUTTON);
     gtk_button_set_image (GTK_BUTTON (dialog->button_back), image);
     gtk_widget_set_sensitive (dialog->button_back, FALSE);
-    gtk_widget_show (dialog->button_back);
     g_signal_connect_swapped (G_OBJECT (dialog->button_back), "clicked",
         G_CALLBACK (xfce_settings_manager_dialog_go_back), dialog);
 
-
-    dialog->button_help = gtk_dialog_add_button (GTK_DIALOG (dialog),
-                                                 _("_Help"), GTK_RESPONSE_HELP);
-    image = gtk_image_new_from_icon_name ("help-browser", GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image (GTK_BUTTON (dialog->button_help), image);
-    button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CLOSE);
-    image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_BUTTON);
+    button = xfce_titled_dialog_add_button (XFCE_TITLED_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CLOSE);
+    image = gtk_image_new_from_icon_name ("window-close-symbolic", GTK_ICON_SIZE_BUTTON);
     gtk_button_set_image (GTK_BUTTON (button), image);
 
-    /* add box at start of the main box */
-    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-    dialog_vbox = gtk_bin_get_child (GTK_BIN (dialog));
-    gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, TRUE, 0);
-    gtk_box_reorder_child (GTK_BOX (dialog_vbox), hbox, 0);
-    gtk_widget_show (hbox);
-
-    /* move the xfce-header in the hbox */
-    children = gtk_container_get_children (GTK_CONTAINER (dialog_vbox));
-    header = g_list_nth_data (children, 1);
-    g_object_ref (G_OBJECT (header));
-    gtk_container_remove (GTK_CONTAINER (dialog_vbox), header);
-    gtk_box_pack_start (GTK_BOX (hbox), header, TRUE, TRUE, 0);
-    g_object_unref (G_OBJECT (header));
-    g_list_free (children);
-
-    ebox = gtk_event_box_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), ebox, FALSE, TRUE, 0);
-    g_signal_connect (header, "style-set",
-        G_CALLBACK (xfce_settings_manager_dialog_header_style), ebox);
-    gtk_widget_show (ebox);
-
+    /* Add the filter box to the Headerbar */
     dialog->filter_entry = entry = gtk_entry_new ();
-    gtk_widget_set_margin_end (GTK_WIDGET (entry), 6);
-    gtk_container_add (GTK_CONTAINER (ebox), entry);
-    gtk_widget_set_halign (entry, GTK_ALIGN_START);
+    gtk_header_bar_pack_end (GTK_HEADER_BAR (gtk_dialog_get_header_bar (GTK_DIALOG (dialog))), entry);
     gtk_widget_set_valign (entry, GTK_ALIGN_CENTER);
     gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, "edit-find");
     gtk_entry_set_icon_activatable (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, FALSE);
@@ -329,7 +301,7 @@ xfce_settings_manager_dialog_init (XfceSettingsManagerDialog *dialog)
     /* pluggable dialog scrolled window and viewport */
     dialog->socket_scroll = scroll = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll), GTK_SHADOW_NONE);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_box_pack_start (GTK_BOX (dialog_vbox), scroll, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (scroll), 0);
 
@@ -416,6 +388,7 @@ xfce_settings_manager_dialog_set_hover_style (XfceSettingsManagerDialog *dialog)
 }
 
 
+
 static void
 xfce_settings_manager_dialog_response (GtkDialog *widget,
                                        gint       response_id)
@@ -463,20 +436,6 @@ xfce_settings_manager_dialog_response (GtkDialog *widget,
 
 
 
-static void
-xfce_settings_manager_dialog_header_style (GtkWidget *header,
-                                           GtkStyle  *old_style,
-                                           GtkWidget *ebox)
-{
-    GtkStyleContext *context;
-
-    context = gtk_widget_get_style_context (ebox);
-    gtk_style_context_add_class (context, "view");
-    gtk_style_context_add_class (context, "XfceHeading");
-}
-
-
-
 static void
 xfce_settings_manager_dialog_set_title (XfceSettingsManagerDialog *dialog,
                                         const gchar               *title,
